@@ -1618,6 +1618,9 @@ sub mkorigtargz {
             uscan_verbose
               "Forcing compression to $Devscripts::MkOrigtargz::found_comp";
             $self->repack(1);
+        } elsif ($path =~ /\.tar$/) {
+            # Always repack uncompressed tarballs
+            $self->repack(1);
         }
         @ARGV = ();
         push @ARGV, "--package", $self->pkg;
